version = "2.0.2"
image_dir = "/usr/local/share/pixmaps/gnome-schedule"
glade_dir = "/usr/local/share/gnome-schedule"
locale_dir = "/usr/local/share/locale"
crontabbin = "/usr/bin/crontab"
atbin = "/usr/bin/at"
atqbin = "/usr/bin/atq"
atrmbin = "/usr/bin/atrm"
batchbin = "/usr/bin/batch"
subin = "/bin/su"
prefix = "/usr/local"

def getPrefix():
	return prefix

def getSubin ():
	return subin

def getAtbin ():
	return atbin

def getAtrmbin ():
	return atrmbin

def getAtqbin ():
	return atqbin

def getBatchbin ():
	return batchbin

def getCrontabbin ():
	return crontabbin

def getVersion ():
	return version

def getImagedir ():
	return image_dir

def getGladedir ():
	return glade_dir

def GETTEXT_PACKAGE():
	return "gnome-schedule"

def GNOMELOCALEDIR():
	return locale_dir
